haze
====

EC2 utility functions and scripts

Rewriting these things every new job is tiresome, so I'm making an open
source version so I can stop having to do that.

Installation
------------

``pip install haze``

License
-------

Everything in this repo is Apache 2.0 licensed.
